@@ -3,23 +3,27 @@
 
 Dynamic Graphics Python
 """
-
 from jsonbourne import json
-from jsonbourne._version import VERSION_INFO
-from jsonbourne._version import VERSION_MAJOR
-from jsonbourne._version import VERSION_MINOR
-from jsonbourne._version import VERSION_PATCH
-from jsonbourne._version import __version__
-from jsonbourne.core import JSON
-from jsonbourne.core import JsonDict
-from jsonbourne.core import JsonObj
-from jsonbourne.core import JsonObjMutableMapping
-from jsonbourne.core import parse
-from jsonbourne.core import stringify
+from jsonbourne._import import import_json
+from jsonbourne._version import (
+    VERSION_INFO,
+    VERSION_MAJOR,
+    VERSION_MINOR,
+    VERSION_PATCH,
+    __version__,
+)
+from jsonbourne.core import (
+    JSON,
+    JsonDict,
+    JsonObj,
+    JsonObjMutableMapping,
+    parse,
+    stringify,
+)
+
 
 JSONLIB = json.__name__
 
-import_json = json.import_json
 __all__ = [
     "JSON",  # js/ts JSON (THE ONE TO USE)
     "json",  # json compat lib
@@ -27,6 +31,8 @@ __all__ = [
     "JsonObjMutableMapping",
     "JsonObj",
     "JsonDict",
+    # import
+    "import_json",
     # util funks
     "stringify",
     "parse",
