@@ -3,6 +3,7 @@
 import keyword
 import sys
 
+from functools import lru_cache
 from itertools import chain
 from pprint import pformat
 from types import ModuleType
@@ -42,6 +43,8 @@ __all__ = [
     "JSON",
 ]
 
+_JsonObjMutableMapping_attrs = set(dir(JsonObjMutableMapping))
+
 
 def is_identifier(string: str) -> bool:
     """Return True if a string is a valid python identifier; False otherwise
@@ -80,6 +83,31 @@ def is_identifier(string: str) -> bool:
     return True
 
 
+def is_float(value: Any) -> bool:
+    """Return True if value is a float"""
+    try:
+        float(value)
+        return True
+    except ValueError:
+        pass
+    return False
+
+
+def is_int(value: Any) -> bool:
+    """Return True if value is a int"""
+    if isinstance(value, int):
+        return True
+    value = str(value)
+    if value[0] in ('-', '+'):
+        return value[1:].isdigit()
+    return value.isdigit()
+
+
+def is_number(value: Any) -> bool:
+    """Return True if value is a number"""
+    return is_int(value) or is_float(value)
+
+
 class JsonObj(JsonObjMutableMapping):
     """JSON friendly python dictionary with dot notation and string only keys
 
@@ -196,6 +224,14 @@ class JsonObj(JsonObjMutableMapping):
             return isinstance(val, MutableMapping) and val.__contains__(rest)
         return key in self.__dict__
 
+    def __setattr__(self, attr, value):
+        if attr in self._cls_protected_attrs():
+            raise ValueError(
+                f"Cannot set protected attribute ('{str(attr)}'),"
+                f" must use brackets/setitem syntax: json_obj['{str(attr)}']"
+            )
+        super(JsonObj, self).__setattr__(attr, value)
+
     def __setitem__(self, key: str, value: Any) -> None:
         """Set JsonObj item with 'key' to 'value'
 
@@ -216,23 +252,16 @@ class JsonObj(JsonObjMutableMapping):
             >>> d
             JsonObj(**{'a': 123, 'b': 321})
             >>> d[123] = 'a'
-            Traceback (most recent call last):
-            ...
-            ValueError: Invalid key: (123).
-            Key cannot be integer or convertable to integer
-            >>> d['123'] = 'a'
-            Traceback (most recent call last):
-            ...
-            ValueError: Invalid key: (123).
-            Key(s) is not a valid python identifier
+            >>> d
+            JsonObj(**{'a': 123, 'b': 321, '123': 'a'})
+            >>> d['456'] = 'a'
+            >>> d
+            JsonObj(**{'a': 123, 'b': 321, '123': 'a', '456': 'a'})
 
         """
-        if isinstance(key, int):
-            raise ValueError(
-                f"Invalid key: ({key}).\n"
-                f"Key cannot be integer or convertable to integer"
-            )
-
+        if is_int(key):
+            self.__dict__[str(key)] = value
+            return None
         if not is_identifier(key):
             raise ValueError(
                 f"Invalid key: ({key}).\n" f"Key(s) is not a valid python identifier"
@@ -265,13 +294,17 @@ class JsonObj(JsonObjMutableMapping):
             2
 
         """
+        if item in _JsonObjMutableMapping_attrs:
+            return object.__getattribute__(self, item)
+        if item in self._cls_protected_attrs():
+            return object.__getattribute__(self, item)
         try:
-            return self.__dict__[item]
+            return self.__getitem__(str(item))
         except KeyError:
             pass
         return object.__getattribute__(self, item)
 
-    def __getattribute__(self, item: str) -> Any:
+    def __object_getattribute__(self, item: str) -> Any:
         return object.__getattribute__(self, item)
 
     def __getitem__(self, key: str) -> Any:
@@ -282,7 +315,7 @@ class JsonObj(JsonObjMutableMapping):
         except KeyError:
             pass
         try:
-            return jsonify(object.__getattribute__(self, key))
+            return jsonify(self.__object_getattribute__(key))
         except AttributeError:
             raise KeyError(str(key))
 
@@ -569,7 +602,7 @@ class JsonObj(JsonObjMutableMapping):
         """Return list of tuples of the form (dot-key, value)"""
         return list(self.dot_items())
 
-    def to_str(self, minify: bool = False, width: int = 120) -> str:
+    def to_str(self, minify: bool = False, width: int = 88) -> str:
         """Return a string representation of the JsonObj object"""
         if minify:
             return type(self).__name__ + "(**" + str(self.to_dict()) + ")"
@@ -618,6 +651,42 @@ class JsonObj(JsonObjMutableMapping):
         except AttributeError:
             raise AttributeError("Class does not inherit from pydantic.BaseModel")
 
+    @classmethod
+    def _cls_protected_attrs(cls) -> Set[str]:
+        """Return attrs-attribute names for an object decorated with attrs"""
+        return {
+            'asdict',
+            'clear',
+            'copy',
+            'dot_items',
+            'dot_items_list',
+            'dot_keys',
+            'dot_keys_list',
+            'dot_keys_set',
+            'dot_lookup',
+            'eject',
+            'entries',
+            'filter_false',
+            'filter_none',
+            'from_dict',
+            'from_json',
+            'fromkeys',
+            'get',
+            'items',
+            'keys',
+            'pop',
+            'popitem',
+            'recurse',
+            'setdefault',
+            'stringify',
+            'to_dict',
+            'to_json',
+            'to_str',
+            'update',
+            'validate_type',
+            'values',
+        }
+
     def _field_names(self) -> Set[str]:
         """Return attrs-attribute names for an object decorated with attrs"""
         return self.__class__._cls_field_names()
@@ -875,5 +944,11 @@ class JSONModuleCls(ModuleType, JSON):
         return jsonify(value)
 
 
+@lru_cache(maxsize=None)
+def _cls_protected_attrs(cls) -> Set[str]:
+    """Return attrs-attribute names for an object decorated with attrs"""
+    return set(dir(cls))
+
+
 stringify = JSON.stringify
 parse = JSON.parse
